@@ -2,7 +2,7 @@
 #-------------------------------------------------------------------------
 # Module: Gbook
 # Author: Jos (josvd@live.nl)
-# Version: 2.2.1
+# Version: 2.2.4
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2009 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -43,7 +43,7 @@ class Gbook extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.2.1';
+		return '2.2.4';
 	}
 
 	function GetHelp()
@@ -103,7 +103,7 @@ class Gbook extends CMSModule
 
 	function MinimumCMSVersion()
 	{
-		return "1.11";
+		return "1.12";
 	}
 
 	function InitializeFrontend()
@@ -222,7 +222,7 @@ class Gbook extends CMSModule
 		}
 		if ( !$result )
 		{
-			echo 'ERROR: ' . mysql_error();
+			echo 'ERROR: ' . $db->ErrorMsg();
 			exit();
 		}
 	}
