@@ -34,17 +34,18 @@ if ( !empty($entry) )
 
 	// get template
 	$template = $this->GetPreference('default_detail_template');
-	if ( !empty($params['template']) && $params['template'] != $template )
+	if (!empty($params['template']))
 	{
 		$template = 'detail_tpl_' . $params['template'];
 	}
-
+/*
 	global $CMS_VERSION;
 	if ( $CMS_VERSION >= '1.11' )
 	{
 		// clear cache for this template
 		$smarty->clearCache($this->GetDatabaseResource($template));
 	}
+ */
 	echo $this->ProcessTemplateFromDatabase($template);
 }
 
