@@ -46,6 +46,8 @@ switch ($params['mode'])
 		if( $_SERVER['REQUEST_METHOD'] == 'POST' )
 		{
 			$params['prevent_post_twice'] = empty($params['prevent_post_twice']) ? 0 : 1;
+			$params['use_captcha'] = empty($params['use_captcha']) ? 0 : 1;
+			$params['allow_rating'] = empty($params['allow_rating']) ? 0 : 1;
 			$params['allow_smilies'] = empty($params['allow_smilies']) ? 0 : 1;
 			$params['allow_notifications'] = empty($params['allow_notifications']) ? 0 : 1;
 			$params['notification_subject'] = '';
@@ -58,6 +60,8 @@ switch ($params['mode'])
 									alias, 
 									entries_page,
 									prevent_post_twice,
+									use_captcha,
+									allow_rating, 
 									allow_smilies, 
 									allow_notifications, 
 									notification_subject,
@@ -69,12 +73,14 @@ switch ($params['mode'])
 									required_fields,
 									active) 
 								VALUES 
-									(?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
+									(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
 			$result = $db->Execute($query, array(
 					$params['name'], 
 					strtolower(munge_string_to_url($params['name'])), 
 					$params['entries_page'], 
 					$params['prevent_post_twice'],
+					$params['use_captcha'],
+					$params['allow_rating'],
 					$params['allow_smilies'],
 					$params['allow_notifications'], 
 					$params['notification_subject'], 
@@ -96,12 +102,14 @@ switch ($params['mode'])
 			$gbook['name'] = '';
 			$gbook['entries_page'] = 10;
 			$gbook['prevent_post_twice'] = 0;
+			$gbook['use_captcha'] = 0;
+			$gbook['allow_rating'] = 0;
 			$gbook['allow_smilies'] = 1;
 			$gbook['allow_notifications'] = 1;
 			$gbook['notification_subject'] = '';
 			$gbook['notification_message'] = '';
 			$gbook['submission_response'] = $this->Lang('submission_response_cnt');
-			$gbook['submission_response_spam'] = $this->Lang('submission_response_spam_cnt');
+			$gbook['submission_response_spam'] = $this->Lang('submission_response_spam_cnt2');
 			$gbook['admin_notification_subject'] = $this->Lang('admin_notification_subject_cnt');
 			$gbook['admin_notification_message'] = $this->Lang('admin_notification_message_cnt');
 			$gbook['required_fields'] = '';
@@ -158,17 +166,27 @@ switch ($params['mode'])
 		if( $_SERVER['REQUEST_METHOD'] == 'POST' )
 		{
 			$params['prevent_post_twice'] = empty($params['prevent_post_twice']) ? 0 : 1;
+			$params['use_captcha'] = empty($params['use_captcha']) ? 0 : 1;
+			$params['allow_rating'] = empty($params['allow_rating']) ? 0 : 1;
 			$params['allow_smilies'] = empty($params['allow_smilies']) ? 0 : 1;
 			$params['allow_notifications'] = empty($params['allow_notifications']) ? 0 : 1;
 			$params['notification_subject'] = '';
 			$params['notification_message'] = '';
 			$params['required_fields'] = empty($params['required_fields']) ? '' : implode(',', $params['required_fields']);
 			$params['active'] = empty($params['active']) ? 0 : 1;
+			
+			if ( $params['use_captcha'] && strpos($params['submission_response_spam'], '{$gbook_captcha}') === false )
+			{
+				$params['submission_response_spam'] = "{* NOTE: this content has changed to add Captcha. Old content see below *} \n\n" . $this->Lang('submission_response_spam_cnt2') . "\n\n\n{* Old content:\n" . $params['submission_response_spam'] . "\n*}";
+			}
+			
 			$query = "UPDATE " . cms_db_prefix() . "module_gbook SET 
 									name = ?, 
 									alias = ?, 
 									entries_page = ?, 
 									prevent_post_twice = ?,
+									use_captcha = ?,
+									allow_rating = ?, 
 									allow_smilies = ?, 
 									allow_notifications = ?, 
 									notification_subject = ?,
@@ -186,6 +204,8 @@ switch ($params['mode'])
 					strtolower(munge_string_to_url($params['name'])), 
 					$params['entries_page'], 
 					$params['prevent_post_twice'],
+					$params['use_captcha'], 
+					$params['allow_rating'], 
 					$params['allow_smilies'], 
 					$params['allow_notifications'], 
 					$params['notification_subject'], 
@@ -252,6 +272,12 @@ $smarty->assign('entries_page', $this->CreateInputText($id, 'entries_page', $gbo
 $smarty->assign('prompt_prevent_post_twice',$this->Lang('prevent_post_twice'));
 $smarty->assign('prevent_post_twice', $this->CreateInputCheckbox( $id, 'prevent_post_twice', 1, $gbook['prevent_post_twice']));
 
+$smarty->assign('prompt_use_captcha',$this->Lang('use_captcha'));
+$smarty->assign('use_captcha', $this->CreateInputCheckbox($id, 'use_captcha', 1, $gbook['use_captcha']));
+
+$smarty->assign('prompt_allow_rating',$this->Lang('allow_rating'));
+$smarty->assign('allow_rating', $this->CreateInputCheckbox( $id, 'allow_rating', 1, $gbook['allow_rating']));
+
 $smarty->assign('prompt_allow_smilies',$this->Lang('allow_smilies'));
 $smarty->assign('allow_smilies', $this->CreateInputCheckbox( $id, 'allow_smilies', 1, $gbook['allow_smilies']));
 
@@ -265,10 +291,10 @@ $smarty->assign('prompt_notification_message',$this->Lang('notification_message'
 $smarty->assign('notification_message', $this->CreateTextArea(false, $id, $gbook['notification_message'], 'notification_message'));
 
 $smarty->assign('prompt_submission_response',$this->Lang('submission_response'));
-$smarty->assign('submission_response', $this->CreateTextArea(true, $id, $gbook['submission_response'], 'submission_response'));
+$smarty->assign('submission_response', $this->CreateTextArea(false, $id, $gbook['submission_response'], 'submission_response'));
 
 $smarty->assign('prompt_submission_response_spam',$this->Lang('submission_response_spam'));
-$smarty->assign('submission_response_spam', $this->CreateTextArea(true, $id, $gbook['submission_response_spam'], 'submission_response_spam'));
+$smarty->assign('submission_response_spam', $this->CreateTextArea(false, $id, $gbook['submission_response_spam'], 'submission_response_spam'));
 
 $smarty->assign('prompt_admin_notification_subject',$this->Lang('admin_notification_subject'));
 $smarty->assign('admin_notification_subject', $this->CreateInputText($id, 'admin_notification_subject', $gbook['admin_notification_subject'], 60 ));
@@ -280,7 +306,8 @@ $smarty->assign('prompt_required_fields',$this->Lang('required_fields'));
 $smarty->assign('required_fields', 
 				$this->CreateInputCheckbox($id, 'required_fields[]', 'name', strpos(' ' . $gbook['required_fields'], 'name') ? 'name' : '') . ' ' . $this->Lang('name') . '<br />' .
 				$this->CreateInputCheckbox($id, 'required_fields[]', 'email', strpos(' ' . $gbook['required_fields'], 'email') ? 'email' : '') . ' ' . $this->Lang('email') . '<br />' .
-				$this->CreateInputCheckbox($id, 'required_fields[]', 'title', strpos(' ' . $gbook['required_fields'], 'title') ? 'title' : '') . ' ' . $this->Lang('title')
+				$this->CreateInputCheckbox($id, 'required_fields[]', 'title', strpos(' ' . $gbook['required_fields'], 'title') ? 'title' : '') . ' ' . $this->Lang('title') . '<br />' .
+				$this->CreateInputCheckbox($id, 'required_fields[]', 'rating', strpos(' ' . $gbook['required_fields'], 'rating') ? 'rating' : '') . ' ' . $this->Lang('rating')
 	);
 
 $smarty->assign('prompt_active',lang('active'));
