@@ -71,7 +71,7 @@ class Gbook_utils
 		}
 		if ( !$result )
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			exit();
 		}
 		return $output;
@@ -151,7 +151,7 @@ class Gbook_utils
 		}
 		if ( !$result )
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			exit();
 		}
 		return $output;
@@ -207,7 +207,7 @@ class Gbook_utils
 		}
 		if ( !$result )
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			exit();
 		}
 		return $output;
@@ -247,6 +247,7 @@ class Gbook_utils
 		$email = trim(strip_tags($email));
 		$title = trim(strip_tags($title));
 		$rating = trim(strip_tags($rating));
+    $rating = empty($rating) ? null : $rating;
 		if ( in_array('name',  $required_fields) && empty($name) ) $errors[] = 'name';
 		if ( in_array('email', $required_fields) && !is_email($email, false) ) $errors[] = 'email';
 		if ( in_array('title', $required_fields) && empty($title) ) $errors[] = 'title';
@@ -314,7 +315,7 @@ class Gbook_utils
 				else
 				{
 					$errors[] = $gbook_id;
-					$errors[] = 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+					$errors[] = 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 					return array('mysql error' => $errors);
 				}
 			}
@@ -385,7 +386,7 @@ class Gbook_utils
 		}
 		else
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			exit();
 		}
 
@@ -419,7 +420,7 @@ class Gbook_utils
 		}
 		else
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			exit();
 		}
 	}
@@ -453,7 +454,7 @@ class Gbook_utils
 		}
 		if ( !$result )
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			echo '<pre>' . $query . '</pre>';
 			exit();
 		}
@@ -478,7 +479,7 @@ class Gbook_utils
 		}
 		if ( !$result )
 		{
-			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 			exit();
 		}
 		return true;
@@ -518,7 +519,7 @@ class Gbook_utils
 			}
 			if ( !$result )
 			{
-				echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+				echo 'ERROR: ' . __LINE__ . ' » ' . $db->ErrorMsg();
 				exit();
 			}
 		}
