@@ -24,6 +24,8 @@ $flds = "
 	alias C(100),
 	entries_page I,
 	prevent_post_twice L,
+	use_captcha L,
+	allow_rating L,
 	allow_smilies L,
 	allow_notifications L,
 	notification_subject C(255),
@@ -46,6 +48,7 @@ $flds = "
 	email C(255),
 	title C(255),
 	message X,
+	rating I,
 	notify L,
 	ip C(40),
 	create_date " . CMS_ADODB_DT . ",
@@ -90,6 +93,8 @@ $query = "INSERT INTO ".cms_db_prefix()."module_gbook (
 						alias, 
 						entries_page, 
 						prevent_post_twice,
+						use_captcha,
+						allow_rating, 
 						allow_smilies, 
 						allow_notifications, 
 						submission_response,
@@ -99,16 +104,18 @@ $query = "INSERT INTO ".cms_db_prefix()."module_gbook (
 						required_fields,
 						active) 
 					VALUES
-						(?,?,?,?,?,?,?,?,?,?,?,?)";
+						(?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
 $result = $db->Execute($query, array(
 						'MyFirstGbook', 
 						'myfistgbook', 
 						10, 
 						0,
+						0,
+						0,
 						1, 
 						0, 
 						$this->Lang('submission_response_cnt'),
-						$this->Lang('submission_response_spam_cnt'),
+						$this->Lang('submission_response_spam_cnt2'),
 						$this->Lang('admin_notification_subject_cnt'),
 						$this->Lang('admin_notification_message_cnt'),
 						'name,email',
